@@ -504,7 +504,7 @@ type contentTableOfContents struct {
 }
 
 type contentSummary struct {
-	content               string
+	content               template.HTML
 	contentWithoutSummary template.HTML
 	summary               page.Summary
 }
@@ -612,9 +612,9 @@ func (c *cachedContentScope) contentRendered(ctx context.Context) (contentSummar
 					Truncated: summarized.Truncated(),
 				}
 				result.contentWithoutSummary = template.HTML(summarized.ContentWithoutSummary())
-				result.content = summarized.Content()
+				result.content = template.HTML(summarized.Content())
 			} else {
-				result.content = string(b)
+				result.content = template.HTML(string(b))
 			}
 
 			if !c.pi.hasSummaryDivider && cp.po.p.m.pageConfig.Summary == "" {
@@ -646,6 +646,7 @@ func (c *cachedContentScope) contentRendered(ctx context.Context) (contentSummar
 				Text: helpers.BytesToHTML(html),
 				Type: page.SummaryTypeFrontMatter,
 			}
+			rs.Value.contentWithoutSummary = rs.Value.content
 		}
 
 		return rs, err
@@ -729,16 +730,15 @@ func (c *cachedContentScope) contentToC(ctx context.Context) (contentTableOfCont
 		isHTML := cp.po.p.m.pageConfig.ContentMediaType.IsHTML()
 
 		if !isHTML {
-			createAndSetToC := func(tocProvider converter.TableOfContentsProvider) {
+			createAndSetToC := func(tocProvider converter.TableOfContentsProvider) error {
 				cfg := p.s.ContentSpec.Converters.GetMarkupConfig()
 				ct.tableOfContents = tocProvider.TableOfContents()
-				ct.tableOfContentsHTML = template.HTML(
-					ct.tableOfContents.ToHTML(
-						cfg.TableOfContents.StartLevel,
-						cfg.TableOfContents.EndLevel,
-						cfg.TableOfContents.Ordered,
-					),
+				ct.tableOfContentsHTML, err = ct.tableOfContents.ToHTML(
+					cfg.TableOfContents.StartLevel,
+					cfg.TableOfContents.EndLevel,
+					cfg.TableOfContents.Ordered,
 				)
+				return err
 			}
 
 			// If the converter supports doing the parsing separately, we do that.
@@ -862,6 +862,10 @@ type cachedContentScope struct {
 }
 
 func (c *cachedContentScope) prepareContext(ctx context.Context) context.Context {
+	// A regular page's shortcode etc. may be rendered by e.g. the home page,
+	// so we need to track any changes to this content's page.
+	ctx = tpl.Context.DependencyManagerScopedProvider.Set(ctx, c.pco.po.p)
+
 	// The markup scope is recursive, so if already set to a non zero value, preserve that value.
 	if s := hugo.GetMarkupScope(ctx); s != "" || s == c.scope {
 		return ctx
@@ -879,7 +883,7 @@ func (c *cachedContentScope) Content(ctx context.Context) (template.HTML, error)
 	if err != nil {
 		return "", err
 	}
-	return template.HTML(cr.content), nil
+	return cr.content, nil
 }
 
 func (c *cachedContentScope) ContentWithoutSummary(ctx context.Context) (template.HTML, error) {
