@@ -77,20 +77,6 @@ func (p *nopPage) Layout() string {
 	return ""
 }
 
-func (p *nopPage) RSSLink() template.URL {
-	return ""
-}
-
-// Deprecated: Use taxonomies instead.
-func (p *nopPage) Author() Author {
-	return Author{}
-}
-
-// Deprecated: Use taxonomies instead.
-func (p *nopPage) Authors() AuthorList {
-	return nil
-}
-
 func (p *nopPage) AllTranslations() Pages {
 	return nil
 }
@@ -167,14 +153,6 @@ func (p *nopPage) ExpiryDate() (t time.Time) {
 	return
 }
 
-func (p *nopPage) Ext() string {
-	return ""
-}
-
-func (p *nopPage) Extension() string {
-	return ""
-}
-
 func (p *nopPage) File() *source.File {
 	return nil
 }
