@@ -31,7 +31,7 @@ import (
 	"github.com/gohugoio/hugo/identity"
 	"github.com/gohugoio/hugo/media"
 	"github.com/gohugoio/hugo/resources"
-	"github.com/gohugoio/hugo/resources/resource_transformers/tocss/internal/sass"
+	"github.com/gohugoio/hugo/resources/resource_transformers/tocss/sass"
 )
 
 // Used in tests. This feature requires Hugo to be built with the extended tag.
@@ -64,7 +64,7 @@ func (t *toCSSTransformation) Transform(ctx *resources.ResourceTransformationCtx
 		}
 	}
 
-	varsStylesheet := sass.CreateVarsStyleSheet(options.from.Vars)
+	varsStylesheet := sass.CreateVarsStyleSheet(sass.TranspilerLibSass, options.from.Vars)
 
 	// To allow for overrides of SCSS files anywhere in the project/theme hierarchy, we need
 	// to help libsass revolve the filename by looking in the composite filesystem first.
@@ -105,7 +105,12 @@ func (t *toCSSTransformation) Transform(ctx *resources.ResourceTransformationCtx
 		} else if strings.HasPrefix(name, "_") {
 			namePatterns = []string{"_%s.scss", "_%s.sass"}
 		} else {
-			namePatterns = []string{"_%s.scss", "%s.scss", "_%s.sass", "%s.sass"}
+			namePatterns = []string{
+				"_%s.scss", "%s.scss",
+				"_%s.sass", "%s.sass",
+				"%s/_index.scss", "%s/_index.sass",
+				"%s/index.scss", "%s/index.sass",
+			}
 		}
 
 		name = strings.TrimPrefix(name, "_")
